[grisbi-cvs] grisbi/src dialog.c, 1.77, 1.78 etats_config.c, 1.174, 1.175 export.h, 1.3, 1.4 gsb_account_property.c, 1.48, 1.49 gsb_archive_config.c, 1.28, 1.29 gsb_bank.c, 1.25, 1.26 gsb_currency_config.h, 1.17, 1.18 gsb_data_reconcile.c, 1.21, 1.22 gsb_file_load.c, 1.202, 1.203 gsb_file_others.c, 1.30, 1.31 gsb_file_save.c, 1.145, 1.146 gsb_real.c, 1.63, 1.64 gsb_real.h, 1.23, 1.24 gsb_reconcile.c, 1.44, 1.45 gsb_scheduler_list.c, 1.77, 1.78 gsb_status.c, 1.20, 1.21 navigation.c, 1.131, 1.132

Pierre Biava pbiava at users.sourceforge.net
Sun Jan 10 21:11:40 CET 2010


Update of /cvsroot/grisbi/grisbi/src
In directory sfp-cvsdas-2.v30.ch3.sourceforge.com:/tmp/cvs-serv13850/src

Modified Files:
	dialog.c etats_config.c export.h gsb_account_property.c 
	gsb_archive_config.c gsb_bank.c gsb_currency_config.h 
	gsb_data_reconcile.c gsb_file_load.c gsb_file_others.c 
	gsb_file_save.c gsb_real.c gsb_real.h gsb_reconcile.c 
	gsb_scheduler_list.c gsb_status.c navigation.c 
Log Message:
fixed bug 834, update strings, and minor corrections

Index: etats_config.c
===================================================================
RCS file: /cvsroot/grisbi/grisbi/src/etats_config.c,v
retrieving revision 1.174
retrieving revision 1.175
diff -u -d -r1.174 -r1.175
--- etats_config.c	29 Aug 2009 08:36:41 -0000	1.174
+++ etats_config.c	10 Jan 2010 20:11:37 -0000	1.175
@@ -6624,7 +6624,8 @@
 		       vbox_show_transactions );
 
     /* demande les détails affichés dans les opérations */
-    paddingbox = new_paddingbox_with_title ( vbox_show_transactions, FALSE, _("Include following informations") );
+    paddingbox = new_paddingbox_with_title ( vbox_show_transactions, FALSE,
+                        _("Include following information") );
     /* connection pour rendre sensitif la frame */
     table = gtk_table_new ( 12, 3, FALSE );
     gtk_box_pack_start ( GTK_BOX (paddingbox), table, FALSE, FALSE, 0 );

Index: gsb_real.h
===================================================================
RCS file: /cvsroot/grisbi/grisbi/src/gsb_real.h,v
retrieving revision 1.23
retrieving revision 1.24
diff -u -d -r1.23 -r1.24
--- gsb_real.h	13 Nov 2009 19:42:02 -0000	1.23
+++ gsb_real.h	10 Jan 2010 20:11:38 -0000	1.24
@@ -47,5 +47,7 @@
                                         const gchar *mon_decimal_point );
 gsb_real gsb_real_sub ( gsb_real number_1,
                         gsb_real number_2 );
+gsb_real gsb_real_import_from_string ( const gchar *string );
+gchar *gsb_real_save_real_to_string ( gsb_real number, gint default_exponent );
 /* END_DECLARATION */
 #endif

Index: gsb_scheduler_list.c
===================================================================
RCS file: /cvsroot/grisbi/grisbi/src/gsb_scheduler_list.c,v
retrieving revision 1.77
retrieving revision 1.78
diff -u -d -r1.77 -r1.78
--- gsb_scheduler_list.c	29 Dec 2009 21:32:09 -0000	1.77
+++ gsb_scheduler_list.c	10 Jan 2010 20:11:38 -0000	1.78
@@ -485,7 +485,7 @@
 
 
 /**
- * change the showed informations on the list :
+ * change the showed information on the list :
  * either show the frequency and mode of the scheduled
  * either show the notes
  *

Index: export.h
===================================================================
RCS file: /cvsroot/grisbi/grisbi/src/export.h,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -d -r1.3 -r1.4
--- export.h	18 Feb 2007 12:37:15 -0000	1.3
+++ export.h	10 Jan 2010 20:11:37 -0000	1.4
@@ -5,7 +5,7 @@
 /* END_INCLUDE_H */
 
 
-/** Structure used to hold exported account informations.  */
+/** Structure used to hold exported account information.  */
 struct exported_account {
     gint account_nb;		/** Account number, to use with
 				 * gsb_data_account_get...() functions */

Index: gsb_real.c
===================================================================
RCS file: /cvsroot/grisbi/grisbi/src/gsb_real.c,v
retrieving revision 1.63
retrieving revision 1.64
diff -u -d -r1.63 -r1.64
--- gsb_real.c	10 Jan 2010 17:10:49 -0000	1.63
+++ gsb_real.c	10 Jan 2010 20:11:38 -0000	1.64
@@ -1027,6 +1027,100 @@
 	return resu;
 }
 
+
+gchar *gsb_real_save_real_to_string ( gsb_real number, gint default_exponent )
+{
+    gchar format[40];
+    gchar *result = NULL;
+    const gchar *sign;
+    const gchar *mon_decimal_point;
+	ldiv_t units;
+
+	if ( (number.exponent < 0)
+    || (number.exponent > sizeofarray ( gsb_real_power_10 ) )
+    || (number.mantissa == error_real.mantissa) )
+      return g_strdup ( "###ERR###" );
+
+    if (number.mantissa == 0)
+        return g_strdup ("0.00");
+
+    if ( default_exponent != -1 )
+        gsb_real_adjust_exponent ( number, default_exponent );
+
+    sign = (number.mantissa < 0) ? "-" : "";
+    mon_decimal_point = ".";
+
+    units = ldiv ( labs (number.mantissa), gsb_real_power_10[number.exponent] );
+    if ( units.quot < 1000 )
+    {
+        g_snprintf (format, sizeof(format), "%s%d%s",
+                                           "%s%d%s%0",
+                                           number.exponent,
+                                           "d" );
+        result = g_strdup_printf ( format, 
+                        sign,
+                        units.quot,
+                        mon_decimal_point,
+                        units.rem );
+    }
+    else
+    {
+        div_t thousands = div ( units.quot, 1000 );
+        if ( thousands.quot < 1000 )
+        {
+            g_snprintf ( format, sizeof (format), "%s%d%s",
+                                                "%s%d%03d%s%0",
+                                                number.exponent,
+                                                "d");
+            result = g_strdup_printf ( format, 
+                            sign,
+                            thousands.quot,
+                            thousands.rem,
+                            mon_decimal_point,
+                            units.rem );
+        }
+        else
+        {
+            div_t millions = div ( thousands.quot, 1000 );
+            if ( millions.quot < 1000 )
+            {
+                g_snprintf ( format, sizeof (format), "%s%d%s",
+                                                    "%s%d%03d%03d%s%0",
+                                                    number.exponent,
+                                                    "d");
+                result = g_strdup_printf ( format, 
+                                sign,
+                                millions.quot,
+                                millions.rem,
+                                thousands.rem,
+                                mon_decimal_point,
+                                units.rem );
+            }
+            else
+            {
+                div_t billions = div ( millions.quot, 1000 );
+                g_snprintf ( format, sizeof (format), "%s%d%s",
+                                                    "%s%d%03d%03d%03d%s%0",
+                                                    number.exponent,
+                                                    "d" );
+                result = g_strdup_printf ( format, 
+                                sign,
+                                billions.quot,
+                                billions.rem,
+                                millions.rem,
+                                thousands.rem,
+                                mon_decimal_point,
+                                units.rem );
+            }
+        }
+    }
+    //~ printf ("number.mantissa = %ld number.exponent = %d résultat = %s\n",
+                        //~ number.mantissa, number.exponent, result );
+
+    return result;
+}
+
+
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */

Index: gsb_file_save.c
===================================================================
RCS file: /cvsroot/grisbi/grisbi/src/gsb_file_save.c,v
retrieving revision 1.145
retrieving revision 1.146
diff -u -d -r1.145 -r1.146
--- gsb_file_save.c	6 Jan 2010 22:17:45 -0000	1.145
+++ gsb_file_save.c	10 Jan 2010 20:11:38 -0000	1.146
@@ -119,7 +119,7 @@
                         gulong *length_calculated,
                         gchar **file_content,
                         gint archive_number );
-static gchar *gsb_file_save_real_to_string ( gsb_real number );
+//~ static gchar *gsb_file_save_real_to_string ( gsb_real number );
 static gulong gsb_file_save_reconcile_part ( gulong iterator,
                         gulong *length_calculated,
                         gchar **file_content );
@@ -160,30 +160,30 @@
 extern gint valeur_echelle_recherche_date_import;
 /*END_EXTERN*/
 
-gchar *gsb_file_save_real_to_string ( gsb_real number )
-{
-	static struct lconv conv = {
-		NULL,
-        NULL,
-        NULL,
-        NULL,
-        NULL,
-        NULL,
-        "",		// mon_thousands_sep
-        NULL,
-        "",		// positive_sign
-        "-",	// negative_sign
-        0,
-        0,
-        0,
-        0,
-        0,
-        0,
-        0,
-        0,
-	};
-	return gsb_real_raw_format_string(number, &conv, NULL);
-}
+//~ gchar *gsb_file_save_real_to_string ( gsb_real number )
+//~ {
+	//~ static struct lconv conv = {
+		//~ NULL,
+        //~ NULL,
+        //~ NULL,
+        //~ NULL,
+        //~ NULL,
+        //~ NULL,
+        //~ "",		// mon_thousands_sep
+        //~ NULL,
+        //~ "",		// positive_sign
+        //~ "-",	// negative_sign
+        //~ 0,
+        //~ 0,
+        //~ 0,
+        //~ 0,
+        //~ 0,
+        //~ 0,
+        //~ 0,
+        //~ 0,
+	//~ };
+	//~ return gsb_real_raw_format_string(number, &conv, NULL);
+//~ }
 
 
 /** 
@@ -239,7 +239,7 @@
 	/* the file exists, we need to get the chmod values
 	 * because gtk will overwrite it */
 	if (stat (filename, &buf) == -1)
-	    /* stat couldn't get the informations, so do as a new file
+	    /* stat couldn't get the information, so do as a new file
 	     * and we will set the good chmod */
 	    do_chmod = TRUE;
 	else
@@ -586,7 +586,7 @@
     gchar *skipped_lines_string;
     gboolean is_archive = FALSE;
 
-    /* prepare stuff to save generals informations */
+    /* prepare stuff to save general information */
 
     /* prepare transactions_view */
     transactions_view = NULL;
@@ -662,7 +662,7 @@
     else
         tmpstr = "";
 
-    /* save the general informations */
+    /* save the general information */
     new_string = g_markup_printf_escaped ( "\t<General\n"
 					   "\t\tFile_version=\"%s\"\n"
 					   "\t\tGrisbi_version=\"%s\"\n"
@@ -861,7 +861,7 @@
 {
     gchar *new_string;
 
-    /* save the print config informations */
+    /* save the print config information */
     new_string = g_markup_printf_escaped ( "\t<Print\n"
 					   "\t\tDraw_lines=\"%d\"\n"
 					   "\t\tDraw_column=\"%d\"\n"
@@ -1014,9 +1014,12 @@
 										       k ));
 
 	/* set the reals */
-	init_balance = gsb_file_save_real_to_string (gsb_data_account_get_init_balance (account_number, -1));
-	mini_wanted = gsb_file_save_real_to_string (gsb_data_account_get_mini_balance_wanted (account_number));
-	mini_auto = gsb_file_save_real_to_string (gsb_data_account_get_mini_balance_authorized (account_number));
+	init_balance = gsb_real_save_real_to_string (
+                        gsb_data_account_get_init_balance ( account_number, -1 ), 2 );
+	mini_wanted = gsb_real_save_real_to_string (
+                        gsb_data_account_get_mini_balance_wanted ( account_number ), 2 );
+	mini_auto = gsb_real_save_real_to_string (
+                        gsb_data_account_get_mini_balance_authorized ( account_number ), 2 );
 
 	/* now we can fill the file content */
 	new_string = g_markup_printf_escaped ( "\t<Account\n"
@@ -1202,9 +1205,12 @@
 
 	/* set the reals. On met en forme le résultat pour avoir une cohérence dans les montants
      * enregistrés dans le fichier à valider */
-	amount = gsb_file_save_real_to_string ( gsb_data_transaction_get_amount (transaction_number) );
-	exchange_rate = gsb_file_save_real_to_string (gsb_data_transaction_get_exchange_rate (transaction_number ));
-	exchange_fees = gsb_file_save_real_to_string (gsb_data_transaction_get_exchange_fees ( transaction_number));
+	amount = gsb_real_save_real_to_string (
+                        gsb_data_transaction_get_amount ( transaction_number ), 2 );
+	exchange_rate = gsb_real_save_real_to_string (
+                        gsb_data_transaction_get_exchange_rate ( transaction_number ), -1 );
+	exchange_fees = gsb_real_save_real_to_string (
+                        gsb_data_transaction_get_exchange_fees ( transaction_number ), 2 );
 	
 	/* set the dates */
 	date = gsb_format_gdate_safe ( gsb_data_transaction_get_date ( transaction_number ));
@@ -1288,7 +1294,8 @@
 	scheduled_number = gsb_data_scheduled_get_scheduled_number (list_tmp -> data);
 
 	/* set the real */
-	amount = gsb_file_save_real_to_string (gsb_data_scheduled_get_amount ( scheduled_number));
+	amount = gsb_real_save_real_to_string (
+                        gsb_data_scheduled_get_amount ( scheduled_number ), 2 );
 
 	/* set the dates */
 	date = gsb_format_gdate_safe (gsb_data_scheduled_get_date ( scheduled_number));
@@ -1608,7 +1615,8 @@
     link_number = gsb_data_currency_link_get_no_currency_link (list_tmp -> data);
 
     /* set the number */
-    change_rate = gsb_file_save_real_to_string (gsb_data_currency_link_get_change_rate (link_number));
+    change_rate = gsb_real_save_real_to_string (
+                        gsb_data_currency_link_get_change_rate ( link_number ), -1 );
 
     /* set the date of modification */
     strdate = gsb_format_gdate_safe ( gsb_data_currency_link_get_modified_date ( link_number ) );
@@ -1840,8 +1848,10 @@
 	    final_date = my_strdup ("");
 
 	/* set the balances strings */
-	init_balance = gsb_file_save_real_to_string (gsb_data_reconcile_get_init_balance (reconcile_number));
-	final_balance = gsb_file_save_real_to_string (gsb_data_reconcile_get_final_balance (reconcile_number));
+	init_balance = gsb_real_save_real_to_string (
+                        gsb_data_reconcile_get_init_balance ( reconcile_number ), 2 );
+	final_balance = gsb_real_save_real_to_string (
+                        gsb_data_reconcile_get_final_balance ( reconcile_number ), 2 );
 
 	/* now we can fill the file content */
 	new_string = g_markup_printf_escaped ( "\t<Reconcile Nb=\"%d\" Na=\"%s\" Acc=\"%d\" Idate=\"%s\" Fdate=\"%s\" Ibal=\"%s\" Fbal=\"%s\" />\n",
@@ -2500,27 +2510,35 @@
 		amount_comparison_number_to_write = amount_comparison_number;
 
 	    /* set the numbers */
-	    first_amount = gsb_file_save_real_to_string (gsb_data_report_amount_comparison_get_first_amount (amount_comparison_number));
-	    second_amount = gsb_file_save_real_to_string (gsb_data_report_amount_comparison_get_second_amount (amount_comparison_number));
+	    first_amount = gsb_real_save_real_to_string (
+                        gsb_data_report_amount_comparison_get_first_amount (
+                        amount_comparison_number ), 2 );
+	    second_amount = gsb_real_save_real_to_string (
+                        gsb_data_report_amount_comparison_get_second_amount (
+                        amount_comparison_number ), 2 );
 
 	    /* now we can fill the file content */
 	    new_string = g_markup_printf_escaped ( "\t<Amount_comparison\n"
-						   "\t\tComparison_number=\"%d\"\n"
-						   "\t\tReport_nb=\"%d\"\n"
-						   "\t\tLast_comparison=\"%d\"\n"
-						   "\t\tComparison_1=\"%d\"\n"
-						   "\t\tLink_1_2=\"%d\"\n"
-						   "\t\tComparison_2=\"%d\"\n"
-						   "\t\tAmount_1=\"%s\"\n"
-						   "\t\tAmount_2=\"%s\" />\n",
-						   amount_comparison_number_to_write,
-						   report_number_to_write,
-						   gsb_data_report_amount_comparison_get_link_to_last_amount_comparison (amount_comparison_number),
-						   gsb_data_report_amount_comparison_get_first_comparison (amount_comparison_number),
-						   gsb_data_report_amount_comparison_get_link_first_to_second_part (amount_comparison_number),
-						   gsb_data_report_amount_comparison_get_second_comparison (amount_comparison_number),
-						   my_safe_null_str(first_amount),
-						   my_safe_null_str(second_amount));
+                        "\t\tComparison_number=\"%d\"\n"
+                        "\t\tReport_nb=\"%d\"\n"
+                        "\t\tLast_comparison=\"%d\"\n"
+                        "\t\tComparison_1=\"%d\"\n"
+                        "\t\tLink_1_2=\"%d\"\n"
+                        "\t\tComparison_2=\"%d\"\n"
+                        "\t\tAmount_1=\"%s\"\n"
+                        "\t\tAmount_2=\"%s\" />\n",
+                        amount_comparison_number_to_write,
+                        report_number_to_write,
+                        gsb_data_report_amount_comparison_get_link_to_last_amount_comparison (
+                        amount_comparison_number ),
+                        gsb_data_report_amount_comparison_get_first_comparison (
+                        amount_comparison_number ),
+                        gsb_data_report_amount_comparison_get_link_first_to_second_part (
+                        amount_comparison_number ),
+                        gsb_data_report_amount_comparison_get_second_comparison (
+                        amount_comparison_number ),
+                        my_safe_null_str(first_amount ),
+                        my_safe_null_str(second_amount ) );
 
 	    g_free (first_amount);
 	    g_free (second_amount);

Index: navigation.c
===================================================================
RCS file: /cvsroot/grisbi/grisbi/src/navigation.c,v
retrieving revision 1.131
retrieving revision 1.132
diff -u -d -r1.131 -r1.132
--- navigation.c	2 Oct 2009 21:35:04 -0000	1.131
+++ navigation.c	10 Jan 2010 20:11:38 -0000	1.132
@@ -718,7 +718,7 @@
 
 
 /**
- * Update informations for an report in navigation pane.
+ * Update information for an report in navigation pane.
  *
  * \param report_nb	Number of the report that has to be updated.
  */
@@ -828,7 +828,7 @@
 
 
 /**
- * Update informations for an account in navigation pane.
+ * Update information for an account in navigation pane.
  *
  * \param account_number	Number of the account that has to be updated.
  */

Index: gsb_archive_config.c
===================================================================
RCS file: /cvsroot/grisbi/grisbi/src/gsb_archive_config.c,v
retrieving revision 1.28
retrieving revision 1.29
diff -u -d -r1.28 -r1.29
--- gsb_archive_config.c	30 Aug 2009 17:59:47 -0000	1.28
+++ gsb_archive_config.c	10 Jan 2010 20:11:37 -0000	1.29
@@ -460,7 +460,7 @@
                         _("Warning, you are about the delete the archive \"%s\".\n\n"
                           "If you continue, all the transactions linked to that archive "
                           "will loose the link and will begin again not archived.\n"
-                          "All the informations about that archive will be destroyed.\n\n"
+                          "All the information about that archive will be destroyed.\n\n"
                           "Do you want to continue ?"),
                         gsb_data_archive_get_name (archive_number) );
     if (!question_yes_no_hint (_("Deleting an archive"), tmpstr , GTK_RESPONSE_CANCEL ))
@@ -525,7 +525,7 @@
                         _("Warning, you are about the delete the archive \"%s\" and its "
                           "associated transactions.\n\nIf you continue, all the transactions "
                           "linked to that archive will be deleted and the initials amounts "
-                          "of the accounts will be adjusted.\nAll the informations about "
+                          "of the accounts will be adjusted.\nAll the information about "
                           "that archive will be destroyed.\nYou should have at least exported "
                           "that archive into another file...\n\nAre you sure you want to "
                           "continue ?"),

Index: gsb_reconcile.c
===================================================================
RCS file: /cvsroot/grisbi/grisbi/src/gsb_reconcile.c,v
retrieving revision 1.44
retrieving revision 1.45
diff -u -d -r1.44 -r1.45
--- gsb_reconcile.c	9 Jan 2010 20:57:38 -0000	1.44
+++ gsb_reconcile.c	10 Jan 2010 20:11:38 -0000	1.45
@@ -93,7 +93,7 @@
 
 /**
  * Create a vbox that contains all controls used to display
- * informations related to current reconciliation.
+ * information related to current reconciliation.
  *
  * \return A newly-allocated frame containing the reconcile widget
  */

Index: gsb_currency_config.h
===================================================================
RCS file: /cvsroot/grisbi/grisbi/src/gsb_currency_config.h,v
retrieving revision 1.17
retrieving revision 1.18
diff -u -d -r1.17 -r1.18
--- gsb_currency_config.h	27 Sep 2009 15:30:49 -0000	1.17
+++ gsb_currency_config.h	10 Jan 2010 20:11:37 -0000	1.18
@@ -6,7 +6,7 @@
 #include "././gsb_real.h"
 /* END_INCLUDE_H */
 
-/** This structure holds informations needed for exchange rates
+/** This structure holds information needed for exchange rates
   cache. */
 struct cached_exchange_rate {
     gint currency1_number;	/** First currency */

Index: gsb_account_property.c
===================================================================
RCS file: /cvsroot/grisbi/grisbi/src/gsb_account_property.c,v
retrieving revision 1.48
retrieving revision 1.49
diff -u -d -r1.48 -r1.49
--- gsb_account_property.c	3 Oct 2009 22:14:56 -0000	1.48
+++ gsb_account_property.c	10 Jan 2010 20:11:37 -0000	1.49
@@ -624,7 +624,7 @@
     gsb_autofunc_textview_set_value ( detail_adresse_titulaire,
                         gsb_data_account_get_holder_address (current_account), current_account );
 
-    /* fill bank informations */
+    /* fill bank information */
     bank_number = gsb_data_account_get_bank (current_account);
 
     gsb_account_property_iban_set_iban (

Index: gsb_data_reconcile.c
===================================================================
RCS file: /cvsroot/grisbi/grisbi/src/gsb_data_reconcile.c,v
retrieving revision 1.21
retrieving revision 1.22
diff -u -d -r1.21 -r1.22
--- gsb_data_reconcile.c	5 Dec 2009 06:54:42 -0000	1.21
+++ gsb_data_reconcile.c	10 Jan 2010 20:11:37 -0000	1.22
@@ -381,23 +381,22 @@
 {
     GList *list_tmp;
 
-    if (!name
-	||
-	!strlen (name))
-	return FALSE;
+    if ( !name || strlen ( name ) == 0 )
+	    return FALSE;
 
     list_tmp = reconcile_list;
 
     while (list_tmp)
     {
-	struct_reconcile *reconcile;
+        struct_reconcile *reconcile;
 
-	reconcile = list_tmp -> data;
+        reconcile = list_tmp -> data;
+        if ( reconcile -> reconcile_name
+         && strlen ( reconcile -> reconcile_name ) == 0
+         && strcmp ( reconcile -> reconcile_name, name ) == 0 )
+            return (reconcile -> reconcile_number);
 
-	if (!strcmp (reconcile -> reconcile_name,
-		     name ))
-	    return (reconcile -> reconcile_number);
-	list_tmp = list_tmp -> next;
+        list_tmp = list_tmp -> next;
     }
 
     return FALSE;

Index: gsb_status.c
===================================================================
RCS file: /cvsroot/grisbi/grisbi/src/gsb_status.c,v
retrieving revision 1.20
retrieving revision 1.21
diff -u -d -r1.20 -r1.21
--- gsb_status.c	29 Aug 2009 08:36:41 -0000	1.20
+++ gsb_status.c	10 Jan 2010 20:11:38 -0000	1.21
@@ -66,7 +66,7 @@
 
 /**
  * Create and return a new GtkStatusBar to hold various status
- * informations.
+ * information.
  *
  * \return	A newly allocated GtkStatusBar.
  */

Index: gsb_file_others.c
===================================================================
RCS file: /cvsroot/grisbi/grisbi/src/gsb_file_others.c,v
retrieving revision 1.30
retrieving revision 1.31
diff -u -d -r1.30 -r1.31
--- gsb_file_others.c	8 Oct 2009 19:02:51 -0000	1.30
+++ gsb_file_others.c	10 Jan 2010 20:11:38 -0000	1.31
@@ -335,7 +335,7 @@
 	gulong result;
     gchar *new_string;
 
-    /* save the general informations */
+    /* save the general information */
 
     new_string = g_strdup_printf ( "\t<General\n"
 				   "\t\tFile_version=\"%s\"\n"

Index: gsb_bank.c
===================================================================
RCS file: /cvsroot/grisbi/grisbi/src/gsb_bank.c,v
retrieving revision 1.25
retrieving revision 1.26
diff -u -d -r1.25 -r1.26
--- gsb_bank.c	17 May 2009 15:53:25 -0000	1.25
+++ gsb_bank.c	10 Jan 2010 20:11:37 -0000	1.26
@@ -930,7 +930,7 @@
 
 
 /**
- * fill the form containing the informations of the bank
+ * fill the form containing the information of the bank
  *
  * \param bank_number the number to fill or -1 to erase the form
  * \param frame the widget containing the form

Index: dialog.c
===================================================================
RCS file: /cvsroot/grisbi/grisbi/src/dialog.c,v
retrieving revision 1.77
retrieving revision 1.78
diff -u -d -r1.77 -r1.78
--- dialog.c	26 Dec 2009 16:57:13 -0000	1.77
+++ dialog.c	10 Jan 2010 20:11:36 -0000	1.78
@@ -54,7 +54,7 @@
       FALSE, FALSE, },
 
     { "ofx-security-not-implemented", N_("Security feature not implemented"),
-      N_("This file contains security informations, which processing is not implemented at "
+      N_("This file contains security information, which processing is not implemented at "
       "this moment."),
       FALSE, FALSE, },
 



More information about the cvs mailing list
Index: gsb_file_load.c
===================================================================
RCS file: /cvsroot/grisbi/grisbi/src/gsb_file_load.c,v
retrieving revision 1.202
retrieving revision 1.203
diff -u -d -r1.202 -r1.203
--- gsb_file_load.c	6 Jan 2010 22:17:45 -0000	1.202
+++ gsb_file_load.c	10 Jan 2010 20:11:37 -0000	1.203
@@ -151,10 +151,6 @@
 static gboolean gsb_file_load_update_previous_version ( void );
 /*END_STATIC*/
 
-/*BEGIN SPECIAL FUNCTION DECLARATION*/
-gsb_real gsb_real_import_from_string ( const gchar *string );
-/*END SPECIAL FUNCTION DECLARATION*/
-
 /*START_EXTERN*/
 extern gchar *adresse_commune;
 extern gchar *adresse_secondaire;
@@ -4785,8 +4781,12 @@
             /* to go to the 0.6.0 we need to change the amount string
              * from 12.340000 to 12.34 before doing the conversion */
             gchar *tmp_string;
+            gsb_real number;
 
             tmp_string = utils_str_reduce_exponant_from_string ( attribute_values[i], 2 );
+            number = gsb_real_get_from_string (tmp_string);
+            //~ printf ("tmp_string = %s number.mantissa = %ld number.exponent = %d\n", tmp_string,
+                        //~ number.mantissa, number.exponent);
             gsb_data_transaction_set_amount ( transaction_number,
                                   gsb_real_get_from_string (tmp_string));
             if (tmp_string) g_free (tmp_string);
@@ -6119,11 +6119,15 @@
     gsb_real number;
     
     tmp_string = utils_str_reduce_exponant_from_string ( text, 2 );
+    printf ("solde_initial = %s\n", tmp_string );
     number = gsb_real_get_from_string ( tmp_string );
     if ( number.mantissa == error_real.mantissa )
         gsb_data_account_set_init_balance ( account_number, null_real );
     else
         gsb_data_account_set_init_balance ( account_number, number );
+    printf ("tmp_string = %s number.mantissa = %ld number.exponent = %d initial_balance = %s\n", tmp_string,
+                        number.mantissa, number.exponent,
+                        gsb_real_get_string ( gsb_data_account_get_init_balance ( account_number, 2)));
 
     if (tmp_string) 
         g_free (tmp_string);
@@ -6141,9 +6145,9 @@
     tmp_string = utils_str_reduce_exponant_from_string ( text, 2 );
     number = gsb_real_get_from_string ( tmp_string );
     if ( number.mantissa == error_real.mantissa )
-        gsb_data_account_set_init_balance ( account_number, null_real );
+        gsb_data_account_set_mini_balance_wanted ( account_number, null_real );
     else
-        gsb_data_account_set_init_balance ( account_number, number );
+        gsb_data_account_set_mini_balance_wanted ( account_number, number );
 
     if (tmp_string) 
         g_free (tmp_string);
@@ -6161,9 +6165,9 @@
     tmp_string = utils_str_reduce_exponant_from_string ( text, 2 );
     number = gsb_real_get_from_string ( tmp_string );
     if ( number.mantissa == error_real.mantissa )
-        gsb_data_account_set_init_balance ( account_number, null_real );
+        gsb_data_account_set_mini_balance_authorized ( account_number, null_real );
     else
-        gsb_data_account_set_init_balance ( account_number, number );
+        gsb_data_account_set_mini_balance_authorized ( account_number, number );
 
     if (tmp_string)
         g_free (tmp_string);
@@ -7744,7 +7748,7 @@
         /* new to 0.6.0 : struct of reconcile has changed,
          * it contains now an account number, init and final dates and
          * init and final balances
          * and now there is no more informations on reconcile in the account
          * so here we try to fill that fields, and especially set the last
          * final date and last final balance in the last reconciles
          * hopefully, we can do that because each reconciled transaction has 
@@ -8051,8 +8055,11 @@
 
     /* if we opened an archive, we say it here */
     if (etat.is_archive)
-    dialogue_hint (_("You have opened an archive.\nThere is no limit in Grisbi, you can do whatever you want and save it later (new reports...) but remember it's an archive before modifying some transactions or important informations."),
-               _("Grisbi archive opened"));
+    dialogue_hint (_("You have opened an archive.\nThere is no limit in Grisbi, "
+                        "you can do whatever you want and save it later (new reports...) "
+                        "but remember it's an archive before modifying some transactions "
+                        "or important information."),
+                        _("Grisbi archive opened"));
     return TRUE;
 }
 
@@ -7744,7 +7748,7 @@
          * it contains now an account number, init and final dates and
          * init and final balances
-         * and now there is no more informations on reconcile in the account
+         * and now there is no more information on reconcile in the account
          * so here we try to fill that fields, and especially set the last
          * final date and last final balance in the last reconciles
